Index: code/branches/notifications/data/gui/scripts/NotificationLayer.lua
===================================================================
--- code/branches/notifications/data/gui/scripts/NotificationLayer.lua	(revision 7342)
+++ code/branches/notifications/data/gui/scripts/NotificationLayer.lua	(revision 7343)
@@ -9,4 +9,6 @@
     local root = winMgr:getWindow("orxonox/NotificationLayer/Root")
     local queue = winMgr:createWindow("MenuWidgets/Listbox", "orxonox/NotificationLayer/Root/Queue/" .. name)
+    queue:setProperty("Alpha", 0.3)
+    queue:setProperty("InheritsAlpha", "setFalse")
     root:addChildWindow(queue)
 
@@ -34,13 +36,4 @@
         winMgr:destroyWindow(queue)
     end
-end
-
-function P.changePosition(name, xPos, yPos)
-    local queue = P.nameToQueueHelper(name)
-    if queue == nil then
-        cout(0, "Queue is nil!")
-        return
-    end
-    queue:setPosition(CEGUI.UVector2(CEGUI.UDim(tonumber(xPos), 0), CEGUI.UDim(tonumber(yPos), 0)))
 end
 
@@ -90,4 +83,23 @@
 end
 
+function P.changePosition(name, xPos, yPos)
+    local queue = P.nameToQueueHelper(name)
+    if queue == nil then
+        cout(0, "Queue is nil!")
+        return
+    end
+    queue:setPosition(CEGUI.UVector2(CEGUI.UDim(tonumber(xPos), 0), CEGUI.UDim(tonumber(yPos), 0)))
+    queue:setWidth(CEGUI.UDim(1.0, -xPos))
+end
+
+function P.changeSize(name, size)
+    local queue = P.nameToQueueHelper(name)
+    if queue == nil then
+        cout(0, "Queue is nil!")
+        return
+    end
+    queue:setHeight(CEGUI.UDim(0, P.queueHeightHelper(queue, size)))
+end
+
 function P.nameToQueueHelper(name)
     local queue = nil
Index: code/branches/notifications/src/modules/notifications/NotificationQueue.cc
===================================================================
--- code/branches/notifications/src/modules/notifications/NotificationQueue.cc	(revision 7342)
+++ code/branches/notifications/src/modules/notifications/NotificationQueue.cc	(revision 7343)
@@ -176,5 +176,5 @@
     /**
     @brief
-        Adds a Notification, to the queue.
+        Adds a Notification to the NotificationQueue.
         It inserts it into the storage containers, creates a corresponding container and pushes the Notification message to the GUI.
     @param notification
@@ -234,5 +234,5 @@
     /**
     @brief
-        Clears the queue by removing all containers.
+        Clears the queue by removing all Notifications.
     */
     void NotificationQueue::clear(void)
@@ -240,7 +240,6 @@
         this->ordering_.clear();
         for(std::vector<NotificationContainer*>::iterator it = this->notifications_.begin(); it != this->notifications_.end(); it++)
-        {
             delete *it;
-        }
+
         this->notifications_.clear();
         this->size_ = 0;
@@ -250,4 +249,13 @@
     /**
     @brief
+        Adjusts the NotificationQueue, when the position has changed.
+    */
+    void NotificationQueue::positionChanged(void)
+    {
+        GUIManager::getInstance().getLuaState()->doString("NotificationLayer.changePosition(\"" + this->getName() + "\", " + multi_cast<std::string>(this->getPosition().x) + ", " + multi_cast<std::string>(this->getPosition().y) + ")");
+    }
+
+    /**
+    @brief
         Sets the name of the NotificationQueue.
     @param name
@@ -274,4 +282,14 @@
     {
         this->maxSize_ = size;
+        this->sizeChanged();
+    }
+
+    /**
+    @brief
+        Adjusts the NotificationQueue, when the maximum size has changed.
+    */
+    void NotificationQueue::sizeChanged(void)
+    {
+        GUIManager::getInstance().getLuaState()->doString("NotificationLayer.changeSize(\"" + this->getName() + "\", " + multi_cast<std::string>(this->getSize()) + ")");
         this->update();
     }
@@ -308,14 +326,10 @@
         string->clear();
         bool first = true;
-        for(std::set<std::string>::const_iterator it = this->targets_.begin(); it != this->targets_.end(); it++) //!< Iterate through the set of targets.
+        for(std::set<std::string>::const_iterator it = this->targets_.begin(); it != this->targets_.end(); it++) // Iterate through the set of targets.
         {
             if(!first)
-            {
                 *string += ',';
-            }
             else
-            {
                 first = false;
-            }
             *string += *it;
         }
@@ -339,5 +353,5 @@
         std::string* pTemp;
         unsigned int index = 0;
-        while( index < targets.size() ) //!< Go through the string, character by character until the end is reached.
+        while(index < targets.size()) // Go through the string, character by character until the end is reached.
         {
             pTemp = new std::string();
@@ -354,12 +368,3 @@
     }
 
-    /**
-    @brief
-        Aligns all the Notifications to the position of the NotificationQueue.
-    */
-    void NotificationQueue::positionChanged(void)
-    {
-        GUIManager::getInstance().getLuaState()->doString("NotificationLayer.changePosition(\"" + this->getName() + "\", " + multi_cast<std::string>(this->getPosition().x) + ", " + multi_cast<std::string>(this->getPosition().y) + ")");
-    }
-
 }
Index: code/branches/notifications/src/modules/notifications/NotificationQueue.h
===================================================================
--- code/branches/notifications/src/modules/notifications/NotificationQueue.h	(revision 7342)
+++ code/branches/notifications/src/modules/notifications/NotificationQueue.h	(revision 7343)
@@ -28,5 +28,5 @@
 
 /**
-    @file
+    @file NotificationQueue.h
     @brief Definition of the NotificationQueue class.
 */
@@ -55,9 +55,9 @@
     struct NotificationContainer
     {
-        Notification* notification; //!< The Notification displayed by the overlay.
+        Notification* notification; //!< The Notification displayed.
         time_t time; //!< The time the Notification was sent and thus first displayed.
     };
 
     //! Struct to allow ordering of NotificationOverlayContainers.
     struct NotificationContainerCompare {
         bool operator() (const NotificationContainer* const & a, const NotificationContainer* const & b) const
@@ -71,5 +71,4 @@
         Damian 'Mozork' Frick
     */
-
     class _NotificationsExport NotificationQueue : public Tickable, public NotificationListener
     {
@@ -134,5 +133,4 @@
             static const unsigned int DEFAULT_SIZE = 5; //!< The default maximum number of Notifications displayed.
             static const unsigned int DEFAULT_DISPLAY_TIME = 30; //!< The default display time.
-
             static const Vector2 DEFAULT_POSITION; //!< the default position.
 
@@ -147,8 +145,8 @@
             std::set<std::string> targets_; //!< The targets the Queue displays Notifications of.
 
-            std::multiset<NotificationContainer*, NotificationContainerCompare> ordering_; //!< Multiset, because the ordering is based on, not necessarily unique, timestamps. //TODO: Would set work as well?
-            std::vector<NotificationContainer*> notifications_;
+            std::multiset<NotificationContainer*, NotificationContainerCompare> ordering_; //!< The NotificationContainers ordered by the time they were registered. //TODO: Would set work as well?
+            std::vector<NotificationContainer*> notifications_; //!< The NotificationContainers in the order they were added to the NotificationQueue.
 
-            float tickTime_; //!< Helper variable, to not have to check for overlays that have been displayed too long, every tick.
+            float tickTime_; //!< Helper variable, to not have to check for Notifications that have been displayed too long, every tick.
             NotificationContainer timeLimit_; //!< Helper object to check against to determine whether Notifications have expired.
 
@@ -156,5 +154,5 @@
 
             void initialize(void); //!< Initializes the object.
-            void create(void);
+            void create(void); //!< Creates the NotificationQueue in lua.
 
             bool setName(const std::string& name); //!< Sets the name of the NotificationQueue.
@@ -163,13 +161,14 @@
             void setDisplayTime(unsigned int time); //!< Sets the maximum number of seconds a Notification is displayed.
 
-            bool setTargets(const std::string & targets); //!< Set the targets of this queue.
+            bool setTargets(const std::string & targets); //!< Set the targets of this NotificationQueue.
 
             void positionChanged(void); //!< Aligns all the Notifications to the position of the NotificationQueue.
+            void sizeChanged(void); //!< Adjusts the NotificationQueue, when the maximum size has changed.
 
-            void push(Notification* notification, const std::time_t & time); //!< Add a notification to the queue.
-            void pop(void);
-            void remove(NotificationContainer* container);
+            void push(Notification* notification, const std::time_t & time); //!< Add a Notification to the NotificationQueue.
+            void pop(void); //!< Removes the least recently added Notification form the NotificationQueue.
+            void remove(NotificationContainer* container); //!< Removes the Notification that is stored in the input container.
 
-            void clear(void); //!< Clear the queue.
+            void clear(void); //!< Clears the queue by removing all Notifications.
 
     };
@@ -55,9 +55,9 @@
     };
 
-    //! Struct to allow ordering of NotificationOverlayContainers.
+    //! Struct to allow ordering of NotificationContainers.
     struct NotificationContainerCompare {
         bool operator() (const NotificationContainer* const & a, const NotificationContainer* const & b) const
